==> phoenix-purchaser-tools-1.0-20201021.033842-90-sources.jar: com/xforceplus/phoenix/tools/transaction/impl/DefaultTransactionLockServiceInvokerImpl.java <==
package com.xforceplus.phoenix.tools.transaction.impl;

import com.xforceplus.phoenix.tools.constant.RedissonConstants;
import com.xforceplus.phoenix.tools.exception.LockException;
import com.xforceplus.phoenix.tools.transaction.BaseLockService;
import com.xforceplus.phoenix.tools.transaction.TransactionLockServiceInvoker;
import com.xforceplus.phoenix.tools.transaction.TransactionServiceInvoker;
import com.xforceplus.phoenix.tools.transaction.consumer.Function3;
import lombok.extern.slf4j.Slf4j;
import org.redisson.api.RLock;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.function.BiFunction;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.function.Supplier;

/**
 * @program: phoenix-purchaser-tools
 * @description
 * @author: wdye
 * @created: 2019-10-28 17:55
 */
@Slf4j
@Component
public class DefaultTransactionLockServiceInvokerImpl extends BaseLockService implements TransactionLockServiceInvoker {

    @Autowired
    private TransactionServiceInvoker transactionServiceInvoker;

    @Override
    public void callNewTxWithLock(RLock lock, Runnable runnable) {
        callNewTxWithLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND, runnable);
    }

    @Override
    public void callNewTxWithLock(RLock lock, long lockLeaseTimeMillISecond, Runnable runnable) {
        boolean releaseLock = true;
        try {
            tryLock(lock, lockLeaseTimeMillISecond);
            transactionServiceInvoker.callNewTx(runnable, lockLeaseTimeMillISecond);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1> void callNewTxWithLock(RLock lock, Consumer<A1> consumer, A1 arg1) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            transactionServiceInvoker.callNewTx(consumer, arg1, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <R> R callNewTxWithLock(RLock lock, Supplier<R> supplier) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            return transactionServiceInvoker.callNewTx(supplier, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, R> R callNewTxWithLock(RLock lock, Function<A1, R> function, A1 arg1) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            return transactionServiceInvoker.callNewTx(function, arg1, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, R> R callNewTxWithLock(RLock lock, long lockLeaseTimeMillISecond, Function<A1, R> function, A1 arg1) {
        boolean releaseLock = true;
        try {
            tryLock(lock, lockLeaseTimeMillISecond);
            return transactionServiceInvoker.callNewTx(function, arg1, lockLeaseTimeMillISecond);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, A2, R> R callNewTxWithLock(RLock lock, BiFunction<A1, A2, R> biFunction, A1 arg1, A2 arg2) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            return transactionServiceInvoker.callNewTx(biFunction, arg1, arg2, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, A2, A3, R> R callNewTxWithLock(RLock lock, long lockLeaseTimeMillISecond, Function3<A1, A2, A3, R> function3, A1 arg1, A2 arg2, A3 arg3) {
        boolean releaseLock = true;
        try {
            tryLock(lock, lockLeaseTimeMillISecond);
            return transactionServiceInvoker.callNewTx(function3, arg1, arg2, arg3, lockLeaseTimeMillISecond);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }


}

==> phoenix-purchaser-tools-1.0-20211220.092725-127-sources.jar: com/xforceplus/phoenix/tools/transaction/impl/DefaultTransactionLockServiceInvokerImpl.java <==
package com.xforceplus.phoenix.tools.transaction.impl;

import com.xforceplus.phoenix.tools.constant.RedissonConstants;
import com.xforceplus.phoenix.tools.exception.LockException;
import com.xforceplus.phoenix.tools.transaction.BaseLockService;
import com.xforceplus.phoenix.tools.transaction.TransactionLockServiceInvoker;
import com.xforceplus.phoenix.tools.transaction.TransactionServiceInvoker;
import com.xforceplus.phoenix.tools.transaction.consumer.Function3;
import com.xforceplus.phoenix.tools.util.AppIdDefiner;
import lombok.extern.slf4j.Slf4j;
import org.redisson.api.RLock;
import org.redisson.api.RedissonClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.function.BiFunction;
import java.util.function.Consumer;
import java.util.function.Function;
import java.util.function.Supplier;

/**
 * @program: phoenix-purchaser-tools
 * @description
 * @author: wdye
 * @created: 2019-10-28 17:55
 */
@Slf4j
@Component
public class DefaultTransactionLockServiceInvokerImpl extends BaseLockService implements TransactionLockServiceInvoker {

    @Autowired
    private TransactionServiceInvoker transactionServiceInvoker;

    @Autowired(required = false)
    private RedissonClient redissonClient;

    @Override
    public void callWithLock(String lockKey, Runnable runnable) {
        final String key = AppIdDefiner.getSimpleId() + lockKey;
        boolean releaseLock = true;
        final RLock lock = redissonClient.getLock(key);
        try {
            fastTryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            runnable.run();
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public void callNewTxWithLock(RLock lock, Runnable runnable) {
        callNewTxWithLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND, runnable);
    }

    @Override
    public void callNewTxWithLock(RLock lock, long lockLeaseTimeMillisecond, Runnable runnable) {
        boolean releaseLock = true;
        try {
            tryLock(lock, lockLeaseTimeMillisecond);
            transactionServiceInvoker.callNewTx(runnable, lockLeaseTimeMillisecond);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1> void callNewTxWithLock(RLock lock, Consumer<A1> consumer, A1 arg1) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            transactionServiceInvoker.callNewTx(consumer, arg1, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <R> R callNewTxWithLock(RLock lock, Supplier<R> supplier) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            return transactionServiceInvoker.callNewTx(supplier, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, R> R callNewTxWithLock(RLock lock, Function<A1, R> function, A1 arg1) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            return transactionServiceInvoker.callNewTx(function, arg1, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, R> R callNewTxWithLock(RLock lock, long lockLeaseTimeMillISecond, Function<A1, R> function, A1 arg1) {
        boolean releaseLock = true;
        try {
            tryLock(lock, lockLeaseTimeMillISecond);
            return transactionServiceInvoker.callNewTx(function, arg1, lockLeaseTimeMillISecond);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, A2, R> R callNewTxWithLock(RLock lock, BiFunction<A1, A2, R> biFunction, A1 arg1, A2 arg2) {
        boolean releaseLock = true;
        try {
            tryLock(lock, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
            return transactionServiceInvoker.callNewTx(biFunction, arg1, arg2, RedissonConstants.LOCK_LEASE_TIME_MILLI_SECOND);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

    @Override
    public <A1, A2, A3, R> R callNewTxWithLock(RLock lock, long lockLeaseTimeMillSecond, Function3<A1, A2, A3, R> function3, A1 arg1, A2 arg2, A3 arg3) {
        boolean releaseLock = true;
        try {
            tryLock(lock, lockLeaseTimeMillSecond);
            return transactionServiceInvoker.callNewTx(function3, arg1, arg2, arg3, lockLeaseTimeMillSecond);
        } catch (LockException e) {
            releaseLock = false;
            throw e;
        } finally {
            unLock(releaseLock, lock);
        }
    }

}
